.. module:: enaml.widgets.dock_area

=======================
enaml.widgets.dock_area
=======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    DockArea


.. autoclass:: DockArea
